@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-# (c) Shrimadhav U K | gautamajay52
+# (c) Shrimadhav U K | gautamajay52 | MaxxRider
 
 import logging
 import os
@@ -8,12 +8,13 @@ import shutil
 
 from pyrogram.types import CallbackQuery
 from tgtlg import AUTH_CHANNEL, MAX_MESSAGE_LENGTH, LOGGER, gDict
-from tgtlg .helper_funcs.admin_check import AdminCheck
-from tgtlg .helper_funcs.download_aria_p_n import aria_start
-from tgtlg .helper_funcs.youtube_dl_button import youtube_dl_call_back
-from tgtlg .plugins.choose_rclone_config import rclone_button_callback
-from tgtlg .plugins.status_message_fn import cancel_message_f
-from tgtlg .helper_funcs.display_progress import Progress
+from tgtlg.helper_funcs.admin_check import AdminCheck
+from tgtlg.helper_funcs.download_aria_p_n import aria_start
+from tgtlg.helper_funcs.youtube_dl_button import youtube_dl_call_back
+from tgtlg.plugins.choose_rclone_config import rclone_button_callback
+from tgtlg.plugins.status_message_fn import cancel_message_f
+from tgtlg.helper_funcs.display_progress import Progress
+
 
 async def button(bot, update: CallbackQuery):
     cb_data = update.data
@@ -32,7 +33,7 @@ async def button(bot, update: CallbackQuery):
         else:
             await bot.answer_callback_query(
                 callback_query_id=update.id,
-                text="not yours.",
+                text="who are you?",
                 show_alert=True,
                 cache_time=0,
             )
@@ -75,14 +76,14 @@ async def button(bot, update: CallbackQuery):
                         else:
                             os.remove(file_name)
                     await i_m_s_e_g.edit_text(
-                        f"Leech cancelled by href='tg://user?id={update.message.from_user.id}'>{update.message.from_user.first_name}</a>"
+                        f"Leech cancelled by <a href='tg://user?id={update.from_user.id}'>{update.from_user.first_name}</a>"
                     )
                 except Exception as e:
                     await i_m_s_e_g.edit_text("<i>FAILED</i>\n\n" + str(e) + "\n#error")
         else:
             await bot.answer_callback_query(
                 callback_query_id=update.id,
-                text="not yours",
+                text="who are you? 🤪🤔🤔🤔",
                 show_alert=True,
                 cache_time=0,
             )
@@ -108,7 +109,7 @@ async def button(bot, update: CallbackQuery):
                 "requirements.txt",
                 "runtime.txt",
                 "start.sh",
-                "tgtlg",
+                "tobrot",
                 "gautam",
                 "tgtlg.txt",
                 "vendor",
@@ -129,11 +130,11 @@ async def button(bot, update: CallbackQuery):
                         shutil.rmtree(f)
                 await update.message.edit_text(f"Deleted {len(g_del_list)} objects.")
             else:
-                await update.message.edit_text("Nothing to clear!")
+                await update.message.edit_text("Nothing to clear.")
         else:
-            await update.message.edit_text("You are not allowed to do that.")
+            await update.message.edit_text("You don't have permission to do that.")
     elif cb_data == "fuckoff":
         await bot.answer_callback_query(
-            update.id, text="trying to cancel...", show_alert=False
+            update.id, text="trying to cancel..", show_alert=False
         )
         await update.message.edit_text("bruh.")
